@@ -11,7 +11,7 @@ import pkg_resources
 
 __package_name__ = 'KGlobal'
 __author__ = 'Kevin Russell'
-__version__ = "1.4.3"
+__version__ = "1.4.4"
 __description__ = '''File, encryption, SQL, XML, and etc...'''
 __url__ = 'https://github.com/KLRussell/Python_KGlobal_Package'
 
@@ -33,4 +33,4 @@ def default_key_dir():
     else:
         path = __path__
 
-    return path
+    return os.path.join(path, "Keys")
